
About
-----

skrub shares much of its DNA with `scikit-learn
<https://scikit-learn.org>`__.

skrub is the continuation of `dirty-cat <http://dirty-cat.github.io>`_
with a broader scope and a broader ambition.

skrub is a fairly young project born from research. We are happy to get feedback
on successes and failures with the different techniques on real world data, or
learn about open datasets on which we can do better examples and empirical work.

skrub received funding from French research projects: `DirtyData
<https://project.inria.fr/dirtydata/>`_ (ANR-17-CE23-0018), `LearnI
<https://anr.fr/Projet-ANR-20-CHIA-0026>`_ (ANR-20-CHIA-0026) and `P16
<https://p16.inria.fr/fr/>`_.
